@@ -11,7 +11,7 @@ See `CircuitPython:board` in CircuitPython for more details.
 """
 
 
-__version__ = "8.42.1"
+__version__ = "8.44.3"
 __repo__ = "https://github.com/adafruit/Adafruit_Blinka.git"
 __blinka__ = True
 
@@ -43,10 +43,9 @@ elif (
     or detector.board.RASPBERRY_PI_CM4
     or detector.board.RASPBERRY_PI_CM4S
     or detector.board.RASPBERRY_PI_400
+    or detector.board.RASPBERRY_PI_5
 ):
     from adafruit_blinka.board.raspberrypi.raspi_4b import *
-elif detector.board.RASPBERRY_PI_5:
-    from adafruit_blinka.board.raspberrypi.raspi_5b import *
 
 elif detector.board.any_raspberry_pi_40_pin:
     from adafruit_blinka.board.raspberrypi.raspi_40pin import *
@@ -327,6 +326,9 @@ elif board_id == ap_board.LUBANCAT2:
 elif board_id == ap_board.LUBANCAT4:
     from adafruit_blinka.board.lubancat.lubancat4 import *
 
+elif board_id == ap_board.LUBANCAT5:
+    from adafruit_blinka.board.lubancat.lubancat5 import *
+
 elif board_id == ap_board.NANOPI_NEO_AIR:
     from adafruit_blinka.board.nanopi.neoair import *
 
